@@ -7,32 +7,11 @@ use Symbol;
 
 my $engine_object;
 
-# holds the current engine cycle
-my $engine_cycles 	= 0;
-my $engine_cycle 	= 0;
-
-#sub run {
-#	my( $self, $request ) = ( shift, shift );
-	
-#	$self->SUPER::run();
-	
-#	if ( $request ) {
-#		$self->handle_request( $request );
-#	}
-	
-#}
-
-
 sub set_engine_object {
     my $self       = shift;
     $engine_object = shift;
 }
 
-sub set_engine_cycles {
-	my $self		= shift;
-	$engine_cycles	= shift;
-}
-
 sub handler {
     my $self = shift;
     eval { $self->handle_request() };
@@ -43,9 +22,13 @@ sub handler {
 
 sub handle_request_test {
     my ( $self, $request ) = @_;
-
-	$ENV{PATH_INFO} = $request if $request;
-	$ENV{SCRIPT_NAME} = "";
+	
+	my( $uri, $args ) = split( /\?/, $request );
+	
+	$ENV{PATH_INFO} 	 	= $uri || $request;
+	$ENV{REQUEST_METHOD} 	= 'GET';
+	$ENV{QUERY_STRING}	 	= $args if $args;
+	$ENV{SCRIPT_NAME} 	 	= "";
 
     # divert STDOUT to another handle that stores the returned data
     my $out_handle      = gensym;
@@ -58,7 +41,7 @@ sub handle_request_test {
         $success_line = $engine_object->dispatch();
     };
     if ( $@ ) {
-        return( '401', $out->get_output() );
+        return( '401', ( "($@)" . ( $out->get_output() ) ) );
     }
 
     # return the result
@@ -110,12 +93,6 @@ EO_FAILURE_RESPONSE
 
     print "HTTP/1.0 $success_code\n" . $out->get_output();
 	
-	# check for exit condition
-	++$engine_cycle;
-	if ( ( $engine_cycle >= $engine_cycles ) && $engine_cycles > 0 ) {
-		return;
-	}
-	
 }
 
 package Gantry::Server::Tier;
